Re-exports
pub use crate::itch_api::ItchClient;
Modules
Structs
- Installed
Upload - Some information about a installed upload
Enums
- Download
Status - Game
Platform - The different platforms a upload can be made for
- Launch
Method
Functions
- download_
game_ cover - Download a game cover image from its game ID
- download_
upload - Download a game upload
- get_
game_ platforms - Find out which platforms a game’s uploads are available in
- get_
upload_ manifest - Retrieve the itch manifest from an installed upload
- get_
web_ game_ url - Get the url to a itch.io web game
- import
- Import an already installed upload
- launch
- Launchs an installed upload
- move
- Move an installed upload to a new game folder
- remove
- Remove an installed upload
- remove_
partial_ download - Remove partially downloaded game files from a cancelled download