remove_partial_download

Function remove_partial_download 

pub async fn remove_partial_download(
    client: &ItchClient,
    upload_id: UploadID,
    game_folder: Option<&Path>,
) -> Result<bool, String>
Remove partially downloaded game files from a cancelled download

Arguments

  • client - An itch.io API client

  • upload_id - The ID of the upload whose download was canceled

  • game_folder - The folder where the game files are currectly placed

Returns

True if something was actually deleted

Errors

If something goes wrong