Module itch_api

Module itch_api 

Modules

errors
types

Structs

ItchClient
A client able to send requests to the itch.io API

Enums

ApiResponse
The itch.io API can respond with either the requested structure or a list of errors
LoginResponse
Response struct for: https://api.itch.io/login

Traits

IntoResponseResult

Functions

get_build_info
Get a build’s info
get_build_scanned_archive
Get additional information about the contents of the build
get_collection_games
List a collection’s games
get_collection_info
Get a collection’s info
get_created_games
Get the games that the user created or that the user is an admin of
get_game_info
Get the information about a game in itch.io
get_game_uploads
Get the game’s uploads (downloadable files)
get_owned_keys
Get the user’s owned game keys
get_profile
Get the API key’s profile
get_profile_collections
List the user’s game collections
get_upgrade_path
Get the upgrade path between two upload builds
get_upload_builds
Get the upload’s builds (downloadable versions)
get_upload_info
Get an upload’s info
get_upload_scanned_archive
Get additional information about the contents of the upload
get_user_info
Get a user’s info
login
Login to itch.io
totp_verification
Complete the login with the TOTP two-factor verification