get_profile

Function get_profile 

pub async fn get_profile(
    client: &ItchClient,
) -> Result<Profile, ItchRequestJSONError<ApiResponseCommonErrors>>
Get the API key’s profile

This can be used to verify that a given itch.io API key is valid

Arguments

  • client - An itch.io API client

Returns

A Profile struct with the info provided by the API

Errors

If the request, retrieving its text, or parsing fails, or if the server returned an error