ItchClient

Struct ItchClient 

pub struct ItchClient { /* private fields */ }
A client able to send requests to the itch.io API

Implementations

Source

impl ItchClient

This block defines the ItchClient constructors and other functions

pub fn get_api_key(&self) -> &str

Obtain the API key associated with this ItchClient

pub fn new(api_key: String) -> Self

Create a new client using the provided itch.io API key, without verifying its validity

Arguments
  • api_key - A valid itch.io API key to store in the client
Returns

An ItchClient struct with the given key

pub async fn auth( api_key: String, ) -> Result<Self, ItchRequestJSONError<ApiResponseCommonErrors>>

Create a new client using the provided itch.io API key and verify its validity

Arguments
  • api_key - A valid itch.io API key to store in the client
Returns

An ItchClient struct with the given key

Errors

If the request, retrieving its text, or parsing fails, or if the server returned an error