pub struct CompressionSettings {
pub algorithm: i32,
pub quality: i32,
}Fields
algorithm: i32quality: i32Implementations
Sourceimpl CompressionSettings
impl CompressionSettings
Sourcepub fn algorithm(&self) -> CompressionAlgorithm
pub fn algorithm(&self) -> CompressionAlgorithm
Returns the enum value of algorithm, or the default if the field is set to an invalid enum value.
Sourcepub fn set_algorithm(&mut self, value: CompressionAlgorithm)
pub fn set_algorithm(&mut self, value: CompressionAlgorithm)
Sets algorithm to the provided enum value.