pub struct Patch<R> {
pub header: PatchHeader,
pub container_old: Container,
pub container_new: Container,
pub sync_op_iter: SyncEntryIter<R>,
}Expand description
Represents a decoded wharf patch file
https://docs.itch.zone/wharf/master/file-formats/patches.html
Contains the header, the old and new containers describing file system state before and after the patch, and an iterator over the patch operations. The iterator reads from the underlying stream on the fly as items are requested.
Fields
header: PatchHeadercontainer_old: Containercontainer_new: Containersync_op_iter: SyncEntryIter<R>Trait Implementations
impl<R> StructuralPartialEq for Patch<R>