pub struct Signature<R> {
pub header: SignatureHeader,
pub container_new: Container,
pub block_hash_iter: BlockHashIter<R>,
}Expand description
Represents a decoded wharf signature file
https://docs.itch.zone/wharf/master/file-formats/signatures.html
Contains the header, the container describing the files/dirs/symlinks, and an iterator over the signature block hashes. The iterator reads from the underlying stream on the fly as items are requested.
Fields
header: SignatureHeadercontainer_new: Containerblock_hash_iter: BlockHashIter<R>Trait Implementations
impl<R> StructuralPartialEq for Signature<R>