Crate scratch_io

Crate scratch_io 

Re-exports

pub use crate::itch_api::ItchClient;

Modules

errors
itch_api
itch_manifest
wharf

Structs

InstalledUpload
Some information about a installed upload

Enums

DownloadStatus
GamePlatform
The different platforms a upload can be made for
LaunchMethod

Functions

download_game_cover
Download a game cover image from its game ID
download_upload
Download a game upload
get_game_platforms
Find out which platforms a game’s uploads are available in
get_upload_manifest
Retrieve the itch manifest from an installed upload
get_web_game_url
Get the url to a itch.io web game
import
Import an already installed upload
launch
Launchs an installed upload
move
Move an installed upload to a new game folder
remove
Remove an installed upload
remove_partial_download
Remove partially downloaded game files from a cancelled download