pub async fn launch(
upload_id: UploadID,
game_folder: &Path,
launch_method: LaunchMethod,
wrapper: &[String],
game_arguments: &[String],
environment_variables: &[(String, String)],
launch_start_callback: impl FnOnce(&Path, &Command),
) -> Result<(), String>Expand description
Launchs an installed upload
Arguments
-
upload_id- The ID of upload which will be launched -
game_folder- The folder where the game uploads are placed -
launch_method- The launch method to use to determine the upload executable file -
wrapper- A list of a wrapper and its options to run the upload executable with -
game_arguments- A list of arguments to launch the upload executable with -
environment_variables- A list of environment variables to be added to the upload executable process’s environment -
launch_start_callback- A callback triggered just before the upload executable runs, providing information about what is about to be executed
Errors
If something goes wrong