pub async fn move(
upload_id: UploadID,
src_game_folder: &Path,
dst_game_folder: &Path,
) -> Result<PathBuf, String>Expand description
Move an installed upload to a new game folder
Arguments
-
upload_id- The ID of upload which will be moved -
src_game_folder- The folder where the game files are currently placed -
dst_game_folder- The folder where the game files will be moved to
Returns
The new game folder in its absolute (canonical) form
Errors
If something goes wrong