Modules
Structs
- Itch
Client - A client able to send requests to the itch.io API
Enums
- ApiResponse
- The itch.io API can respond with either the requested structure or a list of errors
- Login
Response - Response struct for: https://api.itch.io/login
Traits
Functions
- get_
build_ info - Get a build’s info
- get_
build_ scanned_ archive - Get additional information about the contents of the build
- get_
collection_ games - List a collection’s games
- get_
collection_ info - Get a collection’s info
- get_
created_ games - Get the games that the user created or that the user is an admin of
- get_
game_ info - Get the information about a game in itch.io
- get_
game_ uploads - Get the game’s uploads (downloadable files)
- get_
owned_ keys - Get the user’s owned game keys
- get_
profile - Get the API key’s profile
- get_
profile_ collections - List the user’s game collections
- get_
upgrade_ path - Get the upgrade path between two upload builds
- get_
upload_ builds - Get the upload’s builds (downloadable versions)
- get_
upload_ info - Get an upload’s info
- get_
upload_ scanned_ archive - Get additional information about the contents of the upload
- get_
user_ info - Get a user’s info
- login
- Login to itch.io
- totp_
verification - Complete the login with the TOTP two-factor verification