pub async fn get_game_uploads(
client: &ItchClient,
game_id: GameID,
) -> Result<Vec<Upload>, ItchRequestJSONError<GameResponseError>>Expand description
Get the game’s uploads (downloadable files)
Arguments
-
client- An itch.io API client -
game_id- The ID of the game from which information will be obtained
Returns
A vector of Upload structs with the info provided by the API
Errors
If the request, retrieving its text, or parsing fails, or if the server returned an error