pub struct ItchClient { /* private fields */ }Expand description
A client able to send requests to the itch.io API
Implementations
Sourceimpl ItchClient
This block defines the ItchClient constructors and other functions
impl ItchClient
This block defines the ItchClient constructors and other functions
Sourcepub fn get_api_key(&self) -> &str
pub fn get_api_key(&self) -> &str
Obtain the API key associated with this ItchClient
Sourcepub fn new(api_key: String) -> Self
pub fn new(api_key: String) -> Self
Create a new client using the provided itch.io API key, without verifying its validity
Arguments
api_key- A valid itch.io API key to store in the client
Returns
An ItchClient struct with the given key
Sourcepub async fn auth(
api_key: String,
) -> Result<Self, ItchRequestJSONError<ApiResponseCommonErrors>>
pub async fn auth( api_key: String, ) -> Result<Self, ItchRequestJSONError<ApiResponseCommonErrors>>
Create a new client using the provided itch.io API key and verify its validity
Arguments
api_key- A valid itch.io API key to store in the client
Returns
An ItchClient struct with the given key
Errors
If the request, retrieving its text, or parsing fails, or if the server returned an error